@@ -5,9 +5,10 @@ import difflib
 import os
 import re
 import sys
+import warnings
 
 
-__all__ = [
+__all__ = [  # noqa
     'black',
     'blue',
     'cyan',
@@ -141,7 +142,8 @@ def get_code(color, bold=False, reverse=False):
 
     return '\033[' + fmt + color + 'm'
 
-def colorize(s, color, bold=False, reverse=False):
+
+def colorize(s, color, bold=False, reverse=False, start=None, end=None):
     """
     Colorize a string with the color given.
 
@@ -150,11 +152,24 @@ def colorize(s, color, bold=False, reverse=False):
     :type color: :class:`Colors` class
     :param bool bold: Whether to mark up in bold.
     :param bool reverse: Whether to mark up in reverse video.
+    :param int start: Index at which to start coloring.
+    :param int end: Index at which to end coloring.
     :rtype: string
     """
 
-    return ("%s%s%s" % (get_code(color, bold=bold, reverse=reverse),
-                        s, get_code(None)))
+    start = start if start else 0
+    end = end if end else len(s)
+
+    before = s[:start]
+    between = s[start:end]
+    after = s[end:]
+
+    return ("%s%s%s%s%s" % (before,
+                            get_code(color, bold=bold, reverse=reverse),
+                            between,
+                            get_code(None),
+                            after))
+
 
 def wrap_string(s, pos, color, bold=False, reverse=False):
     """
@@ -167,8 +182,13 @@ def wrap_string(s, pos, color, bold=False, reverse=False):
     :param bool bold: Whether to mark up in bold.
     :param bool reverse: Whether to mark up in reverse video.
     :rtype: string
+
+    .. deprecated:: 0.2.2
+       This function has been deprecated in favor of :func:`colorize`.
     """
 
+    warnings.warn("wrap_string is deprecated", PendingDeprecationWarning, 2)
+
     if _disabled:
         if pos == 0:
             pos = 1
